#ifndef NT2_INCLUDE_FUNCTIONS_CSCH_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_CSCH_HPP_INCLUDED

#include <nt2/hyperbolic/include/functions/csch.hpp>

#endif
